OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentāri",
    "You commented" : "Tu komentēji",
    "%1$s commented" : "%1$s komentēja",
    "{author} commented" : "{author} komentēja",
    "You commented on %1$s" : "Tu komentēji %1$s",
    "You commented on {file}" : "Tu komentēji {file}",
    "%1$s commented on %2$s" : "%1$s komentēja %2$s",
    "{author} commented on {file}" : "{author} komentārs {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentāri</strong> datnēm",
    "Edit comment" : "Rediģēt komentāru",
    "Delete comment" : "Dzēst komentāru",
    "No comments yet, start the conversation!" : "Vēl nav komentāru, uzsāciet sarunu!",
    "Retry" : "Mēģināt vēlreiz",
    "_%n unread comment_::_%n unread comments_" : ["%n nelasīti komentāri","%n nelasīti komentāri","%n nelasīti komentāri"],
    "Comment" : "Komentārs",
    "{user} mentioned you in a comment on “{file}”" : "{user} minēja jūs komentārā “{file}”"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
